@@ -1,5 +1,5 @@
 package Algorithm::LUHN_XS;
-$Algorithm::LUHN_XS::VERSION = '1.00';
+$Algorithm::LUHN_XS::VERSION = '1.01';
 require XSLoader;
 XSLoader::load();
 use 5.006;
@@ -198,7 +198,7 @@ which covers them in more detail than this section.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilb/Algorithm-LUHN>
+L<https://github.com/krschwab/Algorithm-LUHN_XS>
 
 =head1 AUTHOR
 
@@ -227,8 +227,10 @@ S<    >L<AnomalousMonk|https://perlmonks.org/?node_id=634253>
 
 S<    >L<BrowserUK|https://perlmonks.org/?node_id=171588>
 
-S<    >L<Corian|https://perlmonks.org/?node_id=5348>
+S<    >L<Corion|https://perlmonks.org/?node_id=5348>
 
 S<    >L<LanX|https://perlmonks.org/?node_id=708738>
 
+S<    >L<tybalt89|https://perlmonks.org/?node_id=1172229>
+
 =cut
